#
# spec file for package libgda
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with fbclient
# BDB: Currently broken.
%bcond_with bdb
%define _name libgda
Name:           libgda
Version:        6.0.0
Release:        9.7
# FIXME: add bdb sql BuildRequires when available
Summary:        GNU Data Access (GDA) Library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Databases/Clients
URL:            https://www.gnome-db.org/
Source:         https://download.gnome.org/sources/libgda/6.0/%{_name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM libgda-javadetection-biarch.patch bgo#673560 -- Prepare getsp to be sed'ed for biarch
Patch1:         libgda-javadetection-biarch.patch
# PATCH-FIX-UPSTREAM overflow-undefined-behavior.patch -- undefined behavior due to overflow
Patch2:         overflow-undefined-behavior.patch
# PATCH-FIX-UPSTREAM libgda-no-gtkdoc-markers.patch glgo#GNOME/libgda#254 dimstar@opensuse.org -- Fix build with GNOME 41 stack
Patch3:         libgda-no-gtkdoc-markers.patch
# PATCH-FIX-UPSTREAM bebdffb4de586fb43fd07ac549121f4b22f6812d.patch boo#1189849 CVE-2021-39359 -- Fix CVE-2021-39359 by forcing TLS certificate validation
Patch4:         https://gitlab.gnome.org/GNOME/libgda/-/commit/bebdffb4de586fb43fd07ac549121f4b22f6812d.patch
# PATCH-FIX-UPSTREAM libgda-fix-meson-060.patch bjorn.lie@gmail.com -- Fix build with meson 0.61.0 and newer
Patch5:         libgda-fix-meson-060.patch
# PATCH-FIX-UPSTREAM https://gitlab.gnome.org/GNOME/libgda/-/merge_requests/192
Patch6:         reproducible.patch

BuildRequires:  db-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  intltool >= 0.40.6
BuildRequires:  itstool
BuildRequires:  java-devel >= 1.8
BuildRequires:  libgcrypt-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libtool
BuildRequires:  mdbtools-devel
BuildRequires:  meson
BuildRequires:  ncurses-devel
BuildRequires:  openldap2-devel
BuildRequires:  pkgconfig
BuildRequires:  postgresql-devel
BuildRequires:  readline-devel
BuildRequires:  unixODBC-devel
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.26.0
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(sqlcipher)
%if %{with fbclient}
BuildRequires:  pkgconfig(fbclient)
%endif
BuildRequires:  pkgconfig(gladeui-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(goocanvas-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtksourceview-3.0)
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libgvc)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(mysqlclient)
BuildRequires:  pkgconfig(sqlite3)
#!BuildIgnore:  openssl

%description
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%package -n glade-catalog-libgda
Summary:        Glade catalog for libgda
Group:          Development/Tools/GUI Builders
Requires:       %{_name}-6_0 = %{version}
Requires:       glade
Supplements:    (glade and %{_name}-devel)

%description -n glade-catalog-libgda
This package provides a catalog for Glade, to allow the use the libgda
widgets in Glade.

%package 6_0-tools
Summary:        GNU Data Access (GDA) Library -- Tools
Group:          Productivity/Databases/Clients
Provides:       %{_name}-6_0 = %{version}
Obsoletes:      %{_name}-6_0 < %{version}

%description 6_0-tools
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

This package provides command-line tools for libgda.

%package -n libgda-ui-6_0-tools
Summary:        GNU Data Access (GDA) Library -- Graphical Tools
Group:          Productivity/Databases/Clients
Supplements:    (%{_name}-6_0-tools and %{_name}-ui-6_0-6_0_0)

%description -n libgda-ui-6_0-tools
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

This package provides graphical tools:
  - gda-browser: a tool to browse databases
  - gda-control-center: configuration tool for libgda

%package -n libgda-6_0-6_0_0
Summary:        GNU Data Access (GDA) Library
Group:          System/Libraries
%if %{with bdb}
Recommends:     %{_name}-6_0-bdb = %{version}
%endif

%description -n libgda-6_0-6_0_0
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%package -n typelib-1_0-Gda-6_0
Summary:        GNU Data Access (GDA) Library -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Gda-6_0
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

This package provides the GObject Introspection bindings for
libgda.

%package -n libgda-ui-6_0-6_0_0
Summary:        GNU Data Access (GDA) Library - UI Widgets
Group:          System/Libraries
Recommends:     iso-codes
Supplements:    (libgda-6_0-6_0_0 and gtk3)

%description -n libgda-ui-6_0-6_0_0
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%package -n typelib-1_0-Gdaui-6_0
Summary:        GNU Data Access (GDA) Library - UI Widgets -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Gdaui-6_0
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

This package provides the GObject Introspection bindings for
libgda-ui.

%package -n libgda-ui-6_0-plugins
Summary:        GNU Data Access (GDA) Library - Plugins for UI Widgets
Group:          System/Libraries
Supplements:    %{_name}-ui-6_0-6_0_0

%description -n libgda-ui-6_0-plugins
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%package report
Summary:        GNU Data Access (GDA) Library
Group:          System/Libraries
Requires:       %{_name}-report-6_0-6_0_0 = %{version}

%description report
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%package -n libgda-report-6_0-6_0_0
Summary:        GNU Data Access (GDA) Library
Group:          System/Libraries
Requires:       %{_name}-report = %{version}

%description -n libgda-report-6_0-6_0_0
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%package -n libgda-xslt-6_0-6_0_0
Summary:        GNU Data Access (GDA) Library
Group:          System/Libraries

%description -n libgda-xslt-6_0-6_0_0
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%package 6_0-devel
Summary:        GNU Data Access (GDA) Library -- Development Files
Group:          Development/Libraries/C and C++
Requires:       %{_name}-6_0-6_0_0 = %{version}
Requires:       %{_name}-report-6_0-6_0_0 = %{version}
Requires:       %{_name}-ui-6_0-6_0_0 = %{version}
Requires:       %{_name}-xslt-6_0-6_0_0 = %{version}
Requires:       typelib-1_0-Gda-6_0 = %{version}
Requires:       typelib-1_0-Gdaui-6_0 = %{version}
# named libgda-devel on 10.3
Provides:       %{_name}-devel = %{version}
Obsoletes:      %{_name}-devel < %{version}

%description 6_0-devel
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

This package contains all necessary include files and libraries needed
to develop applications that require these.

%package 6_0-doc
Summary:        GNU Data Access (GDA) Library -- Developer Documentation
Group:          Development/Libraries/C and C++
Provides:       %{_name}-doc = %{version}
# named libgda-doc on 10.3
Obsoletes:      %{_name}-doc < %{version}

%description 6_0-doc
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%if %{with bdb}
%package 6_0-bdb
Summary:        Berkeley DB Provider for GNU Data Access (GDA)
Group:          Productivity/Databases/Clients
Requires:       %{_name}-6_0-6_0_0 = %{version}

%description 6_0-bdb
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.
%endif

%if %{with fbclient}
%package 6_0-firebird
Summary:        Firebird DB Provider for GNU Data Access (GDA)
Group:          Productivity/Databases/Clients
Requires:       %{_name}-6_0-6_0_0 = %{version}

%description 6_0-firebird
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.
%endif

%package 6_0-ldap
Summary:        LDAP Provider for GNU Data Access (GDA)
Group:          Productivity/Databases/Clients
Requires:       %{_name}-6_0-6_0_0 = %{version}
Supplements:    (libgda-6_0 and %(cd %{_libdir} ; rpm -qf --queryformat=%%{NAME} `readlink %{_libdir}/libldap.so` ))

%description 6_0-ldap
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%package 6_0-mysql
Summary:        MySQL Provider for GNU Data Access (GDA)
Group:          Productivity/Databases/Clients
Requires:       %{_name}-6_0-6_0_0 = %{version}
Supplements:    (libgda-6_0 and %(cd %{_libdir} ; rpm -qf --queryformat=%%{NAME} `readlink %{_libdir}/libmysqlclient.so` ))
Provides:       %{_name}-mysql = %{version}
Obsoletes:      %{_name}-mysql < %{version}

%description 6_0-mysql
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%package 6_0-postgres
Summary:        PostgreSQL Provider for GNU Data Access (GDA)
Group:          Productivity/Databases/Clients
Requires:       %{_name}-6_0-6_0_0 = %{version}
Supplements:    (libgda-6_0 and %(cd %{_libdir} ; rpm -qf --queryformat=%%{NAME} `readlink %{_libdir}/libpq.so` ))
Provides:       %{_name}-postgres = %{version}
Obsoletes:      %{_name}-postgres < %{version}

%description 6_0-postgres
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%package 6_0-sqlcipher
Summary:        SQLCipher Provider for GNU Data Access (GDA)
Group:          Productivity/Databases/Clients
Requires:       %{_name}-6_0-6_0_0 = %{version}
Requires:       %{_name}-6_0-sqlite = %{version}
Enhances:       %{_name}-6_0-sqlite
Provides:       %{_name}-sqlcipher = %{version}

%description 6_0-sqlcipher
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%package 6_0-sqlite
Summary:        Sqlite Provider for GNU Data Access (GDA)
Group:          Productivity/Databases/Clients
Requires:       %{_name}-6_0-6_0_0 = %{version}
Supplements:    (libgda-6_0 and %(cd %{_libdir} ; rpm -qf --queryformat=%%{NAME} `readlink %{_libdir}/libsqlite3.so` ))
Provides:       %{_name}-sqlite = %{version}
Obsoletes:      %{_name}-sqlite < %{version}

%description 6_0-sqlite
GNU Data Access (GDA) is an attempt to provide uniform access to
different kinds of data sources (databases, information servers,
mail spools, etc). It is a complete architecture that provides
everything needed to access data.

%lang_package -n %{_name}-6_0-6_0_0

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%global optflags %{optflags} -fpermissive
export LANG=C.UTF-8
# Patch1 introdcues a --ARCH-- field in getsp, which needs to be replace prior to compilation
getspARCH=%{_target_cpu}
%ifarch x86_64
getspARCH=amd64
%endif
%ifarch %{ix86}
getspARCH=i386
%endif
%ifarch %{arm}
getspARCH=arm
%endif
# IcedTea 2.5.0 have ppc64 as libarch for ppc64le
# except if still build with java 1.7
%ifarch ppc64le
%define ppc64_java %(rpm -qa |grep jdk.devel|grep -Ec '(1_5|1_6)')
%if  0%{ppc64_java}
getspARCH=ppc64
%endif
%endif
%if %{pkg_vcmp java-devel >= 9}
getspARCH=.
%endif
sed -i "s:--ARCH--:$getspARCH:g" getsp.java
# Find the current version of vapigen
VAPIGEN=$(realpath %{_bindir}/vapigen)
VAPIGENVER=${VAPIGEN: -4}
# Due to patch1, getsp.java needs to be rebuilt
javac getsp.java
%meson \
  -Dui=true \
  -Dexperimental=true \
  -Dldap=true \
  -Ddoc=true \
  -Dtools=true \
  %{nil}
%meson_build

%install
# remove error about java bytecode being for something later than java 1.15 -- see http://en.opensuse.org/Java/Packaging/Cookbook
export NO_BRP_CHECK_BYTECODE_VERSION=true
%meson_install
# X-SuSE-Design is just to make the brp check happy...
%suse_update_desktop_file org.gnome.gda.Browser X-SuSE-Design
mv %{buildroot}%{_mandir}/man1/gda-sql.1 %{buildroot}%{_mandir}/man1/gda-sql-6.0.1
sed -e 's-#!/usr/bin/env python3-#!/usr/bin/python3-g' -i %{buildroot}%{_bindir}/t*
chmod 755 %{buildroot}%{_bindir}/*
%find_lang %{_name}-6.0 %{?no_lang_C}
%fdupes %{buildroot}%{_prefix}

%ldconfig_scriptlets -n libgda-6_0-6_0_0
%ldconfig_scriptlets -n libgda-ui-6_0-6_0_0
%ldconfig_scriptlets -n libgda-report-6_0-6_0_0
%ldconfig_scriptlets -n libgda-xslt-6_0-6_0_0

%files -n %{_name}-6_0-6_0_0-lang -f %{_name}-6.0.lang

%files -n glade-catalog-libgda
%{_datadir}/glade/catalogs/*
%{_datadir}/glade/pixmaps/*

%files 6_0-tools
# NOTE: Even if it was probably intended by upstream to be in sync with
# the libgda soname, naming scheme is different (5_0-4 for soname, 5_0
# for data files). To be on the safe side, package it separately.
# This package contains only files with "5.0" in its name or path.
%license COPYING
%doc %{_datadir}/libgda-6.0/gda-sql
%{_bindir}/gda-list-config-6.0
%{_bindir}/gda-list-server-op-6.0
%{_bindir}/gda-sql-6.0
%{_mandir}/man1/gda-sql-6.0.1%{?ext_man}
# in report-5_0-4
%exclude %{_datadir}/libgda-6.0/gda_trml2html
%exclude %{_datadir}/libgda-6.0/gda_trml2pdf

%files -n libgda-ui-6_0-tools
# gda-browser
%{_bindir}/org.gnome.gda.Browser
%{_datadir}/metainfo/org.gnome.gda.Browser.appdata.xml
%{_datadir}/applications/org.gnome.gda.Browser.desktop
%{_datadir}/pixmaps/org.gnome.gda.Browser.png
%{_datadir}/icons/hicolor/512x512/apps/org.gnome.gda.Browser.png
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.gda.Browser.svg
# gda-control-center
%{_bindir}/gda-control-center-6.0

%files -n libgda-6_0-6_0_0
%license COPYING.LIB
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/libgda-6.0.so.*
%dir %{_datadir}/libgda-6.0
%dir %{_datadir}/libgda-6.0/dtd
%{_datadir}/libgda-6.0/information_schema.xml
%{_datadir}/libgda-6.0/dtd/libgda-*.dtd
%dir %{_libdir}/libgda-6.0
%dir %{_libdir}/libgda-6.0/plugins
%dir %{_libdir}/libgda-6.0/providers

%files -n typelib-1_0-Gda-6_0
%{_libdir}/girepository-1.0/Gda-6.0.typelib

%files -n libgda-ui-6_0-6_0_0
%dir %{_datadir}/libgda-6.0/ui
%{_datadir}/libgda-6.0/ui/gdaui-*
%{_libdir}/libgda-ui-6.0.so.*

%files -n typelib-1_0-Gdaui-6_0
%{_libdir}/girepository-1.0/Gdaui-6.0.typelib

%files -n libgda-ui-6_0-plugins
%{_libdir}/libgda-6.0/plugins/libgda-ui-plugins-libgda-6.0.so

%files report
%{_bindir}/trml2html.py
%{_bindir}/trml2pdf.py

%files -n libgda-report-6_0-6_0_0
# NOTE: This library has the same versioning policy, but depends on libgda-sqlite.
%{_datadir}/libgda-6.0/gda_trml2html
%{_datadir}/libgda-6.0/gda_trml2pdf
%{_libdir}/libgda-report-6.0.so.*

%files -n libgda-xslt-6_0-6_0_0
%{_libdir}/libgda-xslt-6.0.so.*

%files 6_0-devel
# NOTE: Files don't conflict with previous version => Use versioned package name
%{_includedir}/libgda-6.0/
%{_libdir}/libgda-6.0.so
%{_libdir}/libgda-xslt-6.0.so
%{_libdir}/libgda-report-6.0.so
%{_libdir}/libgda-ui-6.0.so
%{_libdir}/pkgconfig/*-6.0.pc
%{_datadir}/gir-1.0/*.gir
%{_datadir}/vala/vapi/libgda-6.0.vapi
%{_datadir}/vala/vapi/libgda-6.0.deps
%{_datadir}/vala/vapi/libgdaui-6.0.vapi
# demo
%{_bindir}/org.gnome.gda.Demoui
%{_datadir}/libgda-6.0/demo/

%files 6_0-doc
# NOTE: Files don't conflict with previous version => Use versioned package name
%{_datadir}/gtk-doc/html/libgdaui-6.0/
%{_datadir}/gtk-doc/html/libgda-6.0/

%if %{with bdb}
%files 6_0-bdb
# NOTE: Files don't conflict with previous version => Use versioned package name
%{_libdir}/libgda-6.0/providers/libgda-bdb-6.0.so
%endif

%if %{with fbclient}
%files 6_0-firebird
# NOTE: Files don't conflict with previous version => Use versioned package name
%{_libdir}/libgda-6.0/providers/libgda-firebird-client-6.0.so
%endif

%files 6_0-ldap
# NOTE: Files don't conflict with previous version => Use versioned package name
%{_libdir}/libgda-6.0/providers/libgda-ldap-6.0.so

%files 6_0-mysql
# NOTE: Files don't conflict with previous version => Use versioned package name
%{_libdir}/libgda-6.0/providers/libgda-mysql-6.0.so

%files 6_0-postgres
# NOTE: Files don't conflict with previous version => Use versioned package name
%{_libdir}/libgda-6.0/providers/libgda-postgres-6.0.so

%files 6_0-sqlcipher
# NOTE: Files don't conflict with previous version => Use versioned package name
%license providers/sqlcipher/COPYING.sqlcipher
%{_libdir}/libgda-6.0/providers/libgda-sqlcipher-6.0.so

%files 6_0-sqlite
# NOTE: Files don't conflict with previous version => Use versioned package name
%{_libdir}/libgda-6.0/providers/libgda-sqlite-6.0.so

%changelog
* Thu Jul 11 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Add -fpermissive to optflags to work around C99 violations which
  are errors by default with GCC 14.
- Use ldconfig_scriptlets macro for post(un) handling.
* Tue Feb 13 2024 Pedro Monreal <pmonreal@suse.com>
- Remove the hardcoded libopenssl-1_1-devel to libopenssl-devel.
* Thu Dec 21 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Wed Jun  8 2022 Callum Farmer <gmbr3@opensuse.org>
- Remove mysql to mariadb hack - fixed in mariadb-connector-c
- Remove unnecessary mysql and mariadb BRs - use
  pkgconfig(mysqlclient) instead
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add bebdffb4de586fb43fd07ac549121f4b22f6812d.patch: Fix
  CVE-2021-39359 by forcing TLS certificate validation
  (boo#1189849).
- Add libgda-fix-meson-060.patch: Fix build with meson 0.61.0 and
  newer.
* Fri Nov 12 2021 Callum Farmer <gmbr3@opensuse.org>
- Add missing library requires to devel package
- Move unversioned report binaries to seperate package
* Mon Sep  6 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add libgda-no-gtkdoc-markers.patch: Fix build with GNOME 41
  stack.
* Mon Jul 26 2021 Andreas Schwab <schwab@suse.de>
- overflow-undefined-behavior.patch: Fix undefined behavior due to signed
  integer overflow
* Fri May 21 2021 Callum Farmer <gmbr3@opensuse.org>
- Fix incorrect Requires tag in glade catalog
* Wed Feb 10 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 6.0.0:
  + MySQL: now supports version 8.0
  + PostgreSQL now support GdaText values, so take care because
    some SELECT operations concatenating strings return
    GdaText values instead of strings
  + Lot of memory leaks fixed
  + Added a new module named GdaDB to simplify DDL operations
  + Added database generation from an XML file
  + Updated internal SQLite3 version
  + Added "examples" directory as a target to be built
  + Numerous improvements in CI organization
  + Documentation reorganisation and porting to the new format
  + Code modernized for multiple objects
  + Added new API for GdaConnection object
  + Added uniform LOG_DOMAIN usage between translation units
  + Added Uniform debug code generation
  + Eliminated multiple static global variable
  + Improved code quality for libgda to use -Werror
  + Multiple code improvements, formation, and corrections
  + Batch parsing, should remove spacesa and enters before
    return next statement
  + Only PostgreSQL, MySQL and SQLite providers are supported
  + Improved Meson options name and behavior
- Remove libgda-mysql-bool.patch: contained in upstream
- Remove libgda-no-pg_config.patch: contained in upstream
* Wed Feb  3 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 5.2.10:
  + MySQL: initial support for JSON type
  + MySQL: test against 8.0
  + GdaParser: remove spaces and enters before next statement
  + GdauiSet: fix gdaui_set_source_get_ref_columns() return value
  + SqlParser: fix Vala bindings
  + Vala: added missing variadic methods to VAPI
  + Removing Python 2 support to use Python 3 by default
  + Glade catalog and pixmaps installation directory
    fixed for make distcheck
- Add libgda-mysql-bool.patch: fixes conflicting types
* Wed Nov 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Only conditionally build with firebird support, currently
  disabled (boo#1179203).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Thu Sep 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 5.2.9:
  + Fix Sun JRE 1.8 detection.
  + Fix JDK 11.0 detection.
  + Drop unneeded JAVAH variable check.
  + Fix build for System Installed SQLite libs.
  + Non-Dates and Timestamps values returns 'NULL' string when
    converted.
  + Fix --with-ui, now UI is buildable when enabled.
- Drop patches fixed upstream:
  + libgda-jre18.patch.
  + libgda-jre9.patch.
  + libgda-jre10.patch.
  + libgda-5.2.4-nojavah.patch.
  + libgda-no-libgee.patch.
  + libgda-enable-gdaui-gi.patch: Fixed upstream.
* Wed Apr 10 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 5.2.8 (bsc#1128934):
  + Fix a typo on sv translation
  + Please note: releases 5.2.6 and 5.2.7 were unable to be
    published at downdload.gnome.org
- Changes from version 5.2.4:
  + SQLite provider uses system installed one by default
  + Revome build's date from documentation
  + introspection: removed system install in favor of --prefix
  + Fixed compilation on MacOS
  + All Vala bindings and Vala extensions are built by default
    using --enable-vala, added --disable* switch to disable some or
    all of them
  + Fixes on outdated unit tests
  + Removed unused Vala extensions
  + GdaConnection has removed the use of g_object_weak_*, improving
    multi-threading behaviour
  + Prepared statements now use GWeakRef for weak references
  + GdaDataPivot use instance providers and locking
  + GdaVConnectionDataModel use GRecMutex
  + Updated SQLite to 3.8.11.1
  + Fix SQLCipher build by embedding source code for 3.4.2 version
  + Fix SQLCipher disabling
  + Updated GObject Introspection annotations
  + Fix Doc generation
  + Bugs corrected: #787685 #789382 #761560 #761529 #760420 #761424
    [#754263] #754208
  + Corrected HTML output containing <SCRIPT> tag
  + Correct some truncated help strings
  + Don't use (deprecated) g_thread_supported()
  + MySQL meta data: fixed case where schema is incomplete in MySQL
    database
  + Allow introspection for gda_sql_builder_add_cond_v()
  + SQLite: handle WITHOUT ROWID without any error
  + Updated translations.
- Rebase libgda-5.2.4-nojavah.patch: most of it was merged in time
  for 5.2.8, except one chunk.
- Drop libgda-utf.patch: no longer required.
- Add libgda-no-libgee.patch: do not require libgee, taken from
  upstream git.
- Add libgda-enable-gdaui-gi.patch: Fix configure handling of
  - -enable-gdaui-gi, taken from git.
- Add libgda-no-pg_config.patch: Don't use pg_config, but rather
  pkgconfig: libgda does not build a postgresql server module.
- Pass --with-postgres to configure: ensure to build pgsql support.
* Thu Nov 15 2018 Dominique Leuenberger <dimstar@opensuse.org>
- Update libgda-jre10.patch: Support current and future Java
  versions (up to 19).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Jan  8 2018 fstrba@suse.com
- Added patches:
  * libgda-jre10.patch: detect JRE 10's version string.
  * libgda-5.2.4-nojavah.patch: instead of javah invocation, use
    javac's -h option; this bumps build requirement to
    java-devel >= 1.8
- Modified patches:
  * libgda-jre18.patch
  * libgda-jre9.patch
    + Don't patch generated configure, but the source java.m4 file
- Run spec cleaner and add dependency on autoconf, automake and
  libtool in order to regenearate the configure and Makefile.in
  files.
* Tue Dec  5 2017 dimstar@opensuse.org
- Build against openSSL 1.0 for now:
  + Add libopenssl-1_0_0-devel BuildRequires.
  + BuilgIgnore openssl (the helper programs): they are not needed
    and the build dep would pull in version 1.1, conflicting with
    openssl 1.0 devel packages.
* Mon Nov  6 2017 dimstar@opensuse.org
- Update libgda-jre9.patch: be compatible with Java 9.*;
  javac -version strips trailing 0, so 9.0 is reported as 9,
  whereas 9.0.1 is reported as 9.0.1.
* Tue Oct  3 2017 fstrba@suse.com
- Remove leftover dependency on gcc-java
* Wed Sep 27 2017 dimstar@opensuse.org
- Update libgda-jre9.patch: with the release of JRE 9.0.0, the
  version identifier was changed from 9-internal to 9. Change the
  patch to accept both variants.
* Thu Sep 14 2017 dimstar@opensuse.org
- Fix build with JRE 9:
  + Add libgda-jre9.patch: detect JRE 9's version string.
- Do not run fdupes across default partition boundaries.
- Run spec-cleaner.
* Tue Sep 12 2017 dimstar@opensuse.org
- Add libgda-utf.patch: Do not use UTF-8 chars in headers parsed
  by glib-mkenums. In the build root, this fails otherwise.
* Sat Dec 10 2016 dimstar@opensuse.org
- Automatically find the current version of VALA and pass the
  correct string to --enable-vala VALA_API_VERSION=. This allows us
  not having to change the .spec every 6 months.
* Thu Sep 15 2016 dimstar@opensuse.org
- Build using Vala 0.34: pass --enable-vala VALA_API_VERSION=0.34
  to configure (instead of --enable-vala VALA_API_VERSION=0.32).
* Tue Jul 19 2016 dimstar@opensuse.org
- Drop pkgconfig(fbembed) BuildRequires: pkgconfig(fbclient) is
  sufficient (and fbembed no longer exists).
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Wed Mar 30 2016 dvaleev@suse.com
- Now with Java 1.8, on ppc64le set java arch to ppc64 only
  if we build with java 1.5 or 1.6
* Tue Feb  9 2016 dimstar@opensuse.org
- Pass VALA_API_VERSION=0.32 (instead of 0.30) to configure,
  following the switch to vala 0.31.x/0.32 tree.
* Fri Sep  4 2015 dimstar@opensuse.org
- Pass VALA_API_VERSION=0.30 (instead of 0.28) to configure.
* Mon Aug 31 2015 normand@linux.vnet.ibm.com
- disable getspARCH change for ppc64le when still using jre 1.7
  (required for Leap 42.1)
* Fri Aug 14 2015 dimstar@opensuse.org
- Own %%{_datadir}/appdata (Fix build on Leap).
* Mon Jul 20 2015 zaitor@opensuse.org
- Add libgda-jre18.patch: Fix build with JRE 1.8.
* Fri Jul  3 2015 snuxoll@linux.com
- Development package now includes vapi files, add vala
  BuildRequies and pass --enabl vala to configure.
* Fri Jun 12 2015 zaitor@opensuse.org
- Update to version 5.2.4:
  + Added missing file in distributed tarball (bgo#750891).
- Changes from version 5.2.3:
  + Improved Vala and introspection.
  + Misc bugs fixed.
  + Bugs fixed: bgo#722531, bgo#722773, bgo#730813, bgo# 742312,
    bgo#750191.
  + Updated translations.
* Mon Feb  2 2015 mgorse@suse.com
- Re-enable firebird for s390/s390x.
* Wed Jul  2 2014 dvaleev@suse.com
- change getspARCH to ppc64 on ppc64le
  (Introduced with IcedTea 2.5)
* Mon Dec 23 2013 dimstar@opensuse.org
- Update to version 5.2.2:
  + Avoid using setlocale() in libraries.
  + Bugs fixed: bgo#720594.
  + Updated translations.
- Drop libgda-new-graphviz.patch: fixed upstream.
* Mon Dec 16 2013 uweigand@de.ibm.com
- libgda-new-graphviz.patch: Fix detection of new Graphviz API.
* Sun Dec  8 2013 dimstar@opensuse.org
- Update to version 5.2.1:
  + Fixed a Unix compilation issue (bgo#712143).
  + Improved configure script output.
- Changes from version 5.2.0:
  + Vala bindings improvements.
  + Improvements to most database providers (MySQL, PostgreSQL,
    SQLite, SqlCipher, JDBC, ...).
  + Use SqlCipher 3.0.0 and Sqlite 3.8.0.2.
  + Switched to GTK+3.
  + Lots of work on the Windows platform.
  + Many bugs fixed.
  + Updated translations.
- Drop libgda-old-graphviz.patch and
  libgda-no-return-in-nonvoid.patch: fixed upstream.
- Add itstool BuildRequires: new dependency.
- No longer inject pkgconfig --cflags fbclient into CFLAGS:
  firebird.m4 has since been fixed (bgo#684583).
* Sat Jul 20 2013 dimstar@opensuse.org
- Do not mark %%{_sysconfdir}/libgda-5.0/config as %%dir: RPM 4.11
  became stricter in ensuring the tags are true.
* Sat Mar 16 2013 dimstar@opensuse.org
- Update to version 5.1.2:
  + Many small corrections, some uncovered by CoverityScan.
  + Misc code cleanups, avoid using deprecated functions.
  + MySQL improvements.
  + Vala bindings improvements and corrections.
  + Data export improvements
  + Upgraded SQLite to 3.7.14.1 and SqlCipher to 2.1.1.
  + Have blobs work on Windows.
  + Bugs fixed: bgo#691099, bgo#691069, bgo#669801, bgo#687235,
    bgo#684895, bgo#684583, bgo#684141, bgo#683162.
  + Updated translations.
- Drop libgda-introspect.patch: fixed upstream.
- Add libgda-old-graphviz.patch: re-add support for older graphviz
  versions (< 2.30).
- Add libgda-no-return-in-nonvoid.patch: Fix missing return values
  in non-void functions.
* Fri Dec 28 2012 dvaleev@suse.com
- BuildRequires fbclient and fbembed on ppc64 as well
* Tue Sep 25 2012 cfarrell@suse.com
- license update: GPL-2.0+ and LGPL-2.1+
  Semicolon is ambiguous
* Sat Sep 22 2012 dimstar@opensuse.org
- Update to version 5.1.1:
  + Asynchronous statement execution improvements
  + Added the GDA_STATEMENT_MODEL_OFFLINE flag to specify that
    resulting data model must be readable without requiring a
    server connection
  + Correctly parse "NOT LIKE" and "NOT ILIKE" expressions, and
    hexadecimal notations
  + PostgreSQL: added the "CONNECT_TIMEOUT" option
  + Use Libsecret instead of Libgnome-keyring if available
  + Many other small corrections, code cleanups and deprecated
    functions removal
  + Windows: many code & packaging corrections
  + Many code cleanups to switch to GTK3's features
  + Bugs fixed: bgo#676239, bgo#669801, bgo#680311, bgo#680820,
    bgo#680639
  + Updated translations.
- Add libgda-introspect.patch: fix gobject-introspection parsing.
- Drop libgda-brp.patch and libgda-better-javadetection.patch:
  fixed upstream.
- Replace pkgconfig(gnome-keyring-1) BuildRequires with
  pkgconfig(libsecret-1), following upstream.
- Drop xz BuildRequires as it now comes for free in the build
  system.
* Sat Sep 22 2012 schwab@linux-m68k.org
- Generalize arch detection
* Wed Aug 22 2012 dimstar@opensuse.org
- Update to version 5.1.0:
  + Many Vala bindings improvements
  + Improved Windows packaging scripts
  + GdaBrowser: many small improvements
  + GdaSql: new LDAP commands, better inline help, better visual
    rendering, datasets manipulation
  + Many small corrections, optimizations and bug fixes (Libgda
    core, UI extension, Reports extension, MySQL, virtual
    connections, documentation)
  + Firebird support improvements
  + LDAP: added write support, added connection parameters to
    handle SSL certification chain and size and time limits,
    improved authentification with Active Directory
  + Set SQLite version to 3.7.9 and SqlCipher to 2.0.3
  + MDB tools: handle version 0.7
  + Removed usage of symbols marked as deprecated for Glib 2.32,
    and other code cleanups
  + Bugs fixed: bgo#666356, bgo#667837, bgo#668411, bgo#672874,
    bgo#674715, bgo#674618, bgo#674976.
  + Updated translations.
- Pass --enable-gda-gi and --enable-gdaui-gi to configure to ensure
  we have gobect introspection enabled.
- Replace firebird-devel BuildRequires with pkgconfig(fbclient) and
  pkgconfig(fbembed): firebird packaging was restructured and we
  don't want to follow all the changes there. The pkgconfig()-way
  makes such things transparent to us.
- split out a new libgda-5_0-firebird package.
- Inject pkgconfig --cflags fbclient into CFLAGS, as firebird.m4
  only looks in %%{_prefix}/include for ibase.h.
- Add libgda-brp.patch: Fix brp errors.
* Tue Aug 21 2012 dmueller@suse.com
- fix JNI detection on ARM by extending the --ARCH-- logic in %%%%build
* Sun Jun 17 2012 dimstar@opensuse.org
- Add libgda-better-javadetection.patch: Improve java detection.
- Add libgda-javadetection-biarch.patch: Add capability to also
  correctly detectd on i586. The patch only adds a --ARCH-- field,
  which is replaced using sed during %%build.
- Rebuild getsp.class in %%build section, as above patches touch the
  source of it. Usually, the .class is shipped in the tarball and
  not rebuilt).
* Wed Jan 25 2012 vuntz@opensuse.org
- Update to version 5.0.3:
  + Fixed BDBSql building and running
  + Some MySQL provider corrections
  + Many small corrections and improvements (UI extension,
    GdaNumeric, GdaBrowser, GdaSql)
  + GdaSql: improved inline help and better uniform handling of
    query favorites with GdaBrowser
  + Report engine can now convert rich text to HTML
  + Handle deprecated symbols for Glib 2.32
  + Bugs fixed: bgo#665917, bgo#668411, bgo#667837.
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Fri Dec  9 2011 dimstar@opensuse.org
- Split typelib files into their own subpackages:
  typelib-1_0-Gda-5_0 and typelib-1_0-Gdaui-5_0.
- Add typelib-1_0-Gda-5_0 and typelib-1_0-Gdaui-5_0 and Requires to
  5_0-devel subpackage.
* Mon Nov 28 2011 ro@suse.de
- Do not use firebird-devel BuildRequires on s390, s390x, ppc64.
* Sun Nov 20 2011 dimstar@opensuse.org
- Update to version 5.0.2:
  + Gobject introspection improvements
  + Several small corrections and improvements
  + Better handling of closed connections, allowing some operations
    on closed connections and better error reporting on them
  + GdaNumeric sealing
  + Bugs fixed: bgo#663608
  + Updated translations.
* Sun Nov  6 2011 dimstar@opensuse.org
- Update to version 5.0.1:
  + Fixed Vala bindings generation
  + Several small corrections and improvements
  + Bugs fixed: bgo#662809, bgo#567891, bgo#662922, bgo#597390,
    bgo#663357
  + Updated translations.
* Fri Oct 28 2011 dimstar@opensuse.org
- Update to version 5.0.0:
  + GObject Introspection fixes and automatic Vala bindings
    generation
  + SQLite provider: allow one to load SQLite extensions using
    "SELECT load_extension ('xxx')"
  + Corrected bug when executing statement with a NULL variable
  + New GdaDataPivot object to perform data summarisation
  + Many small corrections and improvements
  + Bugs fixed: bgo#662279, bgo#658643, bgo#622899, bgo#660563,
    bgo#661164, bgo#660344, bgo#661684, bgo#660537.
  + Updated translations.
* Thu Oct  6 2011 vuntz@opensuse.org
- Add iso-codes Recommends to libgdaui-5_0-4 since the
  iso-codes data is used at runtime (but gtkhtml can survive
  without it).
* Fri Sep  2 2011 vuntz@opensuse.org
- Update to version 4.99.4:
  + GdaBrowser: improved LDAP support and other general
    improvements and corrections
  + Many small corrections and improvements (documentation, UI,
    default values handling, use GtkCssProvider, ...)
  + GTK3 deprecations related corrections
  + GObject introspection improvements
  + Better handle parameters valued to NULL in statements
  + Support out of tree UI plugins creation
  + Allow reporting of statement execution's delay
  + Web provider (DB access through a web server) improvements
    (deployment, documentation and performances)
  + Set embedded SQLite's version to 3.7.7.1
  + Bugs corrected: bgo#654370, bgo#654068
  + Updated translations.
* Wed Jul  6 2011 vuntz@opensuse.org
- Update to version 4.99.3:
  + Convert deprecated GTK3 API to new ones
  + Improved compilation system (M4 macros, compiler warnings)
  + PostgreSQL: support the ILIKE operator
  + Misc corrections and improvements
  + Bug fixed: bgo#653082.
  + Updated translations.
- Drop libgda-missing-includes.patch: fixed upstream.
* Tue Jun 21 2011 dimstar@opensuse.org
- Update to version 4.99.2:
  + GDA_TYPE_NULL is not 0 anymore
  + Improved responsiveness when using GdaThreadWrapper
  + Misc. compilation and installation issues corrected
  + MDBTools: distribute missing files
  + GdaBrowser: UI improvements (better LDAP search filter, image
    clipboard copy, text search)
  + Bugs fixed: bgo#651692, bgo#651829, bgo#651922, bgo#652023,
    bgo#652024, bgo#631645, bgo#647633
  + Updated translations.
- Drop pacthes that were merged upstream:
  + libgda-no-subdir-in-bindir.patch
  + libgda-sqlcipher.patch
- Add libgda-missing-includes.patch: Fix implicit declaration error
  raised by brp check. Reported as bgo#653082.
* Thu Jun 16 2011 vuntz@opensuse.org
- Change more pkgconfig() BuildRequires for GNOME 3 port:
  gtksourceview-2.0 to gtksourceview-3.0, goocanvas to
  goocanvas-2.0
* Mon Jun  6 2011 dimstar@opensuse.org
- Update to version 4.99.1:
  + Many GTK3 adaptations (GtkApplication instead of libunique,
    code cleanups)
  + New LDAP provider (read only for the moment)
  + Improvements and corrections from the 4.2 branch
  + Updated translations.
- Create a new subpackage for the ldap provider.
- Re-enable parallel build and remove FIXME note for it.
- Add libgda-sqlcipher.patch: Fix no return in non-void function
  brp error.
- Remove pkgconfig(unique-1.0) BuildRequires after the port to
  GApplication.
* Mon Jun  6 2011 dimstar@opensuse.org
- Update to version 4.99.0:
  + Adaptations to the GTK3 environment:
  - API is preserved but ABI has changed
  - Deprecated API has been removed
  + Embedded SQLite version 3.7.5
  + Embedded SQLCipher version is 2.0Beta
- Changes from version 4.2.5:
  + Corrected regression which prevented correct execution of
    SELECT statements by virtual connections
  + New NSIS based installer for the GdaBrowser tool under Windows
  + Embedd MDBTools when compiling for Windows
  + Misc other corrections
- Changes from version 4.2.4:
  + SQLite provider:
  - Correctly report error messages (for example instead of
    "constraint failed")
  - Correctly report if foreign key constraints are enforced or
    not
  + Added possibility to "declare foreign key constraints", which
    are declarations in the metadata where databases don't actually
    use foreign keys
  + GdaMetaStruct: report information about foreign keys
  + GdaBrowser: many small improvements and corrections
  + GdaSql and GdaBrowser: display more information about database
    providers and DSN's connection parameters, and display
    information about foreign key constraints
  + Documentation improvements and corrections
  + Misc small corrections
  + Bugs fixed: bgo#639533, bgo#639897, bgo#639897, bgo#640482,
    bgo#642037, bgo#642100 and bgo#642170
- Changes from version 4.2.3:
  + Correction to the expression rendering in SQL
  + SQLite: fixed date and related formats when rendering as SQL
  + MySQL: fixed error code ignored and not available via
    gda_connection_event_get_code()
  + Move convenience functions to appropriate classes
  + Documentation updates
  + GdaSql and GdaBrowser: better information about configuration
    and added possibility to clean data files and truncate data
    output to available width
  + Build system fixes
  + Initial support for rich text rendering in reports
  + Misc. improvements
  + Bugs fixed: bgo#636439, bgo#636608, bgo#637010
  + Updated translations.
- Change pkgconfig(gtk+-2.0) BuildRequires to pkgconfig(gtk+-3.0)
  and Supplements in libgdaui-5_0-4 to mention gtk3 instead of
  gtk2.
- Change all 4.0 occurences to 5.0 and 4_0 to 5_0 to folow the new
  version.
* Wed Jun  1 2011 vuntz@opensuse.org
- Move to pkgconfig()-style BuildRequires:
  + Old ones: glib2-devel, goocanvas-devel, graphviz-devel,
    gtksourceview-devel, iso-codes-devel, json-glib-devel,
    libgnome-keyring-devel, libsoup-devel, libunique-devel,
    libxslt-devel, sqlite3-devel.
  + New ones: glib-2.0, gnome-keyring-1, goocanvas, gtk+-2.0,
    gtksourceview-2.0, iso-codes, json-glib-1.0, libgvc,
    libsoup-2.4, libxml-2.0, libxslt, sqlite3, unique-1.0.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Mon Dec  6 2010 vuntz@opensuse.org
- Update to version 4.2.2:
  + GdaBrowser: better take user preferences into account
  + new GdauiRtEditor widget and plugin
  + bug fixes: bgo#635377, bgo#635419 and misc.
  + Updated translations.
- Use --with-libdir-name instead of --with-bdb-libdir-name, since
  it will work for all other backends too.
* Mon Nov 15 2010 dimstar@opensuse.org
- Update to version 4.2.1:
  + code cleanups and compilation warnings removal
  + more annotations for GObject Introspection
  + removed old database providers' code
  + build system improvements
  + GdaBrowser improvements: error reporting in data manager
    perspective, authentification dialog
  + documentation corrections
  + updated SQLCipher to version 1.1.8
  + optimized virtual tables usage
  + improved GdaDataModel import and export
  + MySQL provider: support for statements where the prepared
    statement API does not work
  + Bugs fixed: bgo#630655, bgo#630953, bgo#617550, bgo#633247,
    bgo#634737 and other minor ones.
  + Updated translations.
- Pass --with-bdb-libdir-name=%%{_lib} to configure: the configure
  script was changed and doesn't work anymore for 64-bits systems.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 4.2.0:
  + Misc corrections.
  + Updated translations.
- Update descriptions of packages.
- Create a libgda-tools subpackage, that contains unversioned
  binaries. Pass --enable-default-binary to configure so that we
  always get the unversioned binaries.
- Rename the libgda-4_0 suppackage to libgda-4_0-tools, with
  appropriate Provides and Obsoletes.
- Split graphical tools out of libgda-4_0-tools in
  libgda-ui-4_0-tools. Add a Supplements to install this subpackage
  automatically if libgda-4_0-tools and the libgda-ui library are
  installed.
- Remove Requires for libgda-4_0 in libgda-report-4_0-4: this is
  not needed.
- Remove Requires for libgda-4_0 in libgda-4_0-doc: this is not
  needed.
- Move some files around, so that they get installed with the right
  subpackage.
- Remove the sales_test.db database: it's just there as a test, and
  should not be in the package.
* Wed Sep 15 2010 vuntz@opensuse.org
- Update to version 4.1.11:
  + Misc corrections
  + New SQLCipher provider (integrated SQLCipher into Libgda) to
    encrypt SQLite databases
  + Updated translations.
- Add a libgda-4_0-sqlcipher subpackage, for the new provider.
* Sat Sep 11 2010 vuntz@opensuse.org
- Update to version 4.1.10:
  + GdaBrowser improvements & corrections (better full screen mode
    and notifications, improved data manager perspective and more)
  + Misc corrections
  + Updated translations.
* Thu Sep  2 2010 vuntz@opensuse.org
- Update to version 4.1.8:
  + Improved core API (GdaSqlBuilder, GdaServerOperation,
    GdaThreadWrapper, GdaConnection)
  + Core corrections and optimization, mainly in the SQLite and
    MySQL providers, connection (locking and thread safe usage)
  + Use Gnome Keyring if available to store username and passwords
    to be used for data sources (DSN)
  + Configuration file monitoring: only use GIO (removed GnomeVFS,
    gamin or FAM)
  + Many improvements to the UI extension
  + Many improvements and corrections to the GdaBrowser tool
  + Update version of embedded SQLite to 3.6.22
  + Updated translations.
- Add libgnome-keyring-devel BuildRequires.
- Drop libgda-fix-introspection-build.patch: fixed upstream.
* Sat Aug  7 2010 vuntz@opensuse.org
- Add libgda-fix-introspection-build.patch to fix build:
  g-ir-compiler isn't able to parse a header with virtual methods
  that are not explicitly typed.
- Remove gnome-vfs2-devel Requires from devel package.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 4.1.7:
  + new provider for Oracle Berkeley DB's SQL frontend (which has
    the same API as sqlite)
  + added CREATE_USER and DROP_USER server operations (only for
    PostgreSQL at the moment)
  + added a new GDA_CONNECTION_OPTIONS_THREAD_ISOLATED connection
    option
  + better display invalid values in form and grid widgets
  + Lots of GObject introspection annotations added
  + Better MacOSX support: binary relocation corrections, bundle
    making script for the GdaBrowser
  + GdaSqlBuilder API improvements
  + Corrected memory leak in SQLite provider
  + Renamed configure.in to configure.ac
  + Corrections in the Gda-Sql tool regarding username and password
  + Misc. corrections: connection locking issues, honor the
    GDA_EASY_CREATE_TABLE_UNIQUE_FLAG flag, some optimizations
  + Documentation corrections, and code cleanups
  + Updated translations
- Changes from version 4.1.6:
  + register GdaStatement as a boxed type
  + GdaSqlBuilder API simplifications and other corrections
  + GdauiLogin widget corrections
  + Updated translations
- Changes from version 4.1.5:
  + support BLOBS in MySQL provider
  + meta data correction for PostgreSQL provider
  + Do not set GErrors without a domain for the PostgreSQL provider
  + honor the request for the last inserted row in the MySQL
    provider
  + fetch indexes information for MySQL
  + fixed reading float values in the MySQL provider
  + corrected the MySQL and SQLite boolean handlers
  + API improvements to the GdaSqlBuilder object
  + new Data Manager perspective in the GdaBrowser
  + added help in GdaBrowser
  + initial GObject introspection for the UI extension
  + improved GObject introspection support
  + removed deprecaded GTK+ symbols usage
  + use accessor functions instead direct access (enable GSEAL)
  + new UI extension example
  + doc. corrections & improvements
  + better handle GCJ as the java compiler
  + lots of bug fixes and other improvements
  + Updated translations
- Remove workarounds for mis-installation of gir files and header.
- Disable parallel build as it breaks the build at the moment.
- Move gir files to devel package.
* Wed Apr 28 2010 dimstar@opensuse.org
- BuildRequire pkg-config in order to produce useful pkgconfig()
  provides.
* Mon Jan 18 2010 vuntz@opensuse.org
- Manually install libgda.h, which is not installed anymore in
  4.1.4 (bgo#607357).
* Sat Jan 16 2010 vuntz@opensuse.org
- Update to version 4.1.4:
  + API improvements: GdaSqlBuilder, UI extension
  + new Web provider to access databases through a web server
  + WIN32 related corrections
  + GNOME 3.0 and GSeal corrections
  + initial support for GObject Introspection (for libgda only)
  + meta data now include indexes information
  + improved icons
  + JDBC provider: don't keep the JVM loaded when not necessary
  + embedd SQLite 3.6.22
  + GdaBrowser improvements and corrections: connections bindings,
    loading CSV files, table's columns' preferences
  + misc bug fixes and other improvements
  + Updated translations.
- Rebase libgda-no-subdir-in-bindir.patch to apply without fuzz.
- Create libgda-4_0-web subpackage for the new web provider.
- Add gobject-introspection-devel BuildRequires, and package
  introspection files. Add a workaround for misinstallation of gir
  file in wrong directory.
* Fri Dec  4 2009 vuntz@opensuse.org
- Update to version 4.1.3:
  + GdaBrowser improvement
  + UI extension corrections
  + libgda's core improvements: better BLOB handling, better API
    for GdaSqlBuilder, GdaDataSelect
  + misc bug fixes
  + Updated translations.
- Add firebird-devel, goocanvas-devel, graphviz-devel,
  gtksourceview-devel, iso-codes-devel, libunique-devel,
  readline-devel BuildRequires.
- Do not make everything depend on libgda-4_0, and move files where
  they really belong. This also implies renaming the lang package
  to libgda-4_0-4-lang.
- Create 4_0-bdb and ui-4_0-plugins subpackages.
- Fix self-obsoletion of libgda-devel.
* Mon Sep 28 2009 vuntz@opensuse.org
- Update to version 4.1.2:
  + the GdaBrowser application now supports query execution, and is
    more polished and stable
  + Lots of bug fixes mainly related to threads usage and the UI
    extension
  + Updated translations.
- Drop libgda-4.1.1-brperrors.patch: fixed upstream.
- Drop libgda-browser-icons.patch: fixed upstream.
* Fri Sep  4 2009 vuntz@novell.com
- Add libgda-no-subdir-in-bindir.patch to not create a subdirectory
  in bindir (bgo#594115).
- Add libgda-browser-icons.patch to look for icons in the right
  directory.
* Mon Aug 24 2009 dimstar@opensuse.org
- Update to version 4.1.1:
  + it is now possible to use a system installed SQLite, and now
    uses SQLite 3.6.17 if embedded
  + new Oracle driver (provider)
  + improved MySQL and PostgreSQL drivers (providers)
  + console program improvements
  + new UI extension based on GTK+
  + new program to manage data sources graphically
  + new program to "browse" a database's schema
  + improved documentation
  + better handle SQL identifiers
  + Lots of corrections and small improvements
  + Updated translations.
- Add libgda-4.1.1-brperrors.patch to fix missing includes.
- Drop libgda-4.1-97723be0.patch and libgda-4.1.0-am111.patch.
- Remove gnome-common BuildRequire.
- Split libgda-ui-4_0-4 out.
- Drop the non versioned packaed. For updaters it's provided by
  libgda-4_0.
* Fri Jul 31 2009 dominique-obs@leuenberger.net
- Update to version 4.1.0:
  + API and ABI compatible with 4.0.x versions
  + new API to execute statement asynchronously
  + new API to build DML (SELECT, INSERT, UPDATE and DELETE)
    statements the easy way
  + new flag to open a connection in a sub thread, to be able to
    use a connection from several threads, even if the connection
    does not support it
  + the GdaMetaStore object is now thread safe
  + new API to represent data organized as trees
  + new API to execute a single statement several times, each
    execution with different parameters' values
  + documentation and examples improvements
  + bug fixes
  + Updated translations.
- Add libgda-4.1-97723be0.patch, taken from upstream git
- Add libgda-4.1.0-am111.patch, taken as a part from upstream git
  commit 0cbad26e1.
- Due to the two patches, BuildRequire gnome-common and call
  gnome-autogen.sh.
* Sat Jun 13 2009 vuntz@novell.com
- Add json-glib-devel BuildRequires.
* Sat Mar 28 2009 vuntz@novell.com
- Update to version 4.0.1:
  + make sure Libgda's GdaMetaStore object behaves correctly even
    if the SQLite provider is not installed
  + misc. corrections
* Mon Mar 16 2009 vuntz@novell.com
- Update to version 4.0.0:
  + Documentation fixes.
* Sun Mar 15 2009 vuntz@novell.com
- Update to version 3.99.14:
  + misc. corrections
  + use XDG Base Directory Specification to store DSN list
  + bug fixes: bgo#574736, bgo#574738, bgo#574742, bgo#574740
* Tue Mar 10 2009 vuntz@novell.com
- Update to version 3.99.13:
  + misc. corrections
  + load LibDB only when needed
  + bug fixes: bgo#574021, bgo#574193
- Drop libgda-1.0.3-ncurses.patch: fixed upstream.
* Sun Mar  1 2009 mboman@suse.de
- Update to version 3.99.12:
  + misc. corrections
  + MySQL, SQLite and PostgreSQL providers improvements and
    corrections
  + documentation and examples improvements
  + SQLite version is now 3.6.11
  + Bugs fixed: bgo#572028, bgo#571879, bgo#572220, bgo#542847,
    bgo#572734, bgo#572394
  + Translation updates
- Remove %%{release} from all Requires
- Remove BuildRequires; fam-devel, gnome-common, gnome-vfs2-devel,
  gtk-doc, libgio-fam, readline-devel, scrollkeeper, sgml-skel,
  xbase-devel
- Use Requires %%{name} = %%{version} instead of
  %%{name} >= %%{version}
- Remove -fno-strict-aliasing from compiler flags, and subsequently
  remove compiler flags all together as $RPM_OPT_FLAGS are default
- Don't use autoreconf
- Don't use --enable-debug and --enable-gtk-doc with configure
* Fri Feb 13 2009 vuntz@novell.com
- Update to version 3.99.11:
  + misc. corrections
  + documentation improvements
  + bug fixes: bgo#570396, bgo#570251, bgo#570315, bgo#570787
- Changes from version 3.99.10:
  + corrections
  + cleanups
  + documentation improvements
  + bug fixes: bgo#568570, bgo#568731, bgo#568844, bgo#561748,
    bgo#568388, bgo#486021, bgo#143576, bgo#568484, bgo#570220
- Changes from version 3.99.9:
  + corrections
  + cleanups
  + documentation improvements
  + bug fixes: bgo#561173, bgo#561175, bgo#568163, bgo#568165
- Changes from version 3.99.8:
  + misc corrections
  + SQL console: better useability in the web console
  + SQL console: man page added
  + Win32 build fixes
- Add export NO_BRP_CHECK_BYTECODE_VERSION=true to remove an error
  that we can ignore according to the wiki.
- Re-enable BuildRequires on mdbtools-devel and xbase-devel.
- Create 4_0-mdb package.
* Sat Jan 31 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn.
* Sat Jan 17 2009 msuman@suse.de
- Update to version 3.99.7:
  + This is a major re-write of the core parts of Libgda, and is
    API incompatible with the 3.x versions. Changes include:
  - Easier to understand and to use API, with less strange path
    usage - Reduce the size of the library (almost half the
    size, half the symbols) - Easier connection opening (removal
    of the GdaClient object) - Merge of the GdaQuery and
    GdaCommand into only one object to represent statements
  - New adaptative SQL parser (can be adaptated to each DBMS's
    SQL syntax) - New database based dictionary which can
    handle namespaces - Rework of the database adaptators
    (providers) for easier maintenance and more features
  - Sample "skeleton" database adaptators to make it easy to
    write a database adaptator for a new database type
  - Updated documentation
  + Uses GIO instead of GnomeVFS
  + Preliminary MacOS X support, and better support for cross
    compilation + New JDBC provider (allows access to any database
    through a JDBC driver) NOTE: This is currently not built.
  + Updated translations
- Drop libgda-vfsmonitor.patch (GIO will be used really soon now,
  so no need to rebase).
- Drop libgda-return.patch (fixed upstream).
* Sat Jan 17 2009 crrodriguez@suse.de
- remove "la" files, baby step to clean up all references
  to libavahi-*.la
* Sun Oct  5 2008 mboman@suse.de
- Backrev to version 3.1.2:
  + 3.99.3 is unstable and should not have gone in.
* Fri Sep  5 2008 mboman@novell.com
- Update to version 3.99.3:
  - Lots of bug fixed, memory leaks fixes and general performance
  improvements. See NEWS for full details.
  - Bugs fixed: bgo#524837, bgo#525601, bgo#525877, bgo#526748,
  bgo#527892, bgo#527002, bgo#534805, bgo#536418, bgo#536971,
  bgo#537558, bgo#537117
- Removed libgda-return.patch. Source changed.
- Removed libgda-vfsmonitor.patch. Uses GIO now.
* Mon May  5 2008 coolo@suse.de
- return values in non-void functions
* Fri Mar 14 2008 aj@suse.de
- Fix broken dependency.
* Mon Feb 18 2008 maw@suse.de
- Update to version 3.1.2:
  + Filtering based on an SQL expression is now possible in the
    GdaDataProxy data model
  + New XSL extension which uses Libgda
  + Documentation improvements and examples
  + Tools: improvements to the SQL console and new tool to list
    the possible server operations for each provider
  + Bug fixed: bgo#486017, and bgo#484112
  + Firebird database provider now almost fully working (BLOBs are
    not yet writable, no prepared statement used)
  + MS Access database provider reworked to support all the
    SQLite's SQL (don't depend on libmdbsql.so anymore for SQL
    processing)
  + LDAP provider has seen a first draft rework
  + Use of environment variables to specify debug ourput of
    commands and connection events
  + "LIMIT" and "OFFSET" keywords recognized, for bug bgo#488860
  + Enhanced the SQL console tool (allow multiple connections
    and virtual connections)
  + Many small corrections and improvements
  + Updated translations
- Remove libgda-1.0.3-lib64.patch, libgda-uninitialized.patch, and
  libgda-implicit-decl.patch, which have been upstreamed
- New subpackage: libgda-xslt-3_0-0.
* Tue Dec  4 2007 sbrabec@suse.cz
- Reduced BuildRequires.
* Fri Nov  2 2007 sbrabec@suse.cz
- Use packageand supplements for additional modules packages.
* Wed Oct 24 2007 sbrabec@suse.cz
- Fixed devel package splitting (#336197).
* Sun Oct 21 2007 coolo@suse.de
- correctly obsolete old version
* Fri Oct 19 2007 sbrabec@suse.cz
- Split package according to library packaging policy.
* Tue Oct 16 2007 sbrabec@suse.cz
- Fixed devel requires.
* Wed Oct  3 2007 sbrabec@suse.cz
- Updated to version 3.1.1:
  * New major version, new API. See NEWS for details.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Thu Dec 14 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
- Splitted libgda-doc from libgda-devel.
* Mon Apr  3 2006 lmichnovic@suse.cz
- fixed wrong variable set [#159399]
* Fri Feb 17 2006 danw@suse.de
- remove libgda-fam-gamin-dload.patch and add a new patch to do
  file notification via gnome-vfs (and update requires accordingly).
  Part of plan to get rid of gamin, #128037.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan  5 2006 sbrabec@suse.cz
- Use Enhances where appropriate.
* Tue Nov  8 2005 sbrabec@suse.cz
- Use sqlite3.
- Fix and build Berkeley DB module.
* Wed Oct 26 2005 rodrigo@suse.de
- Added fix for syslog vulnerability (#130698)
* Tue Oct 25 2005 rhafer@suse.de
- added LDAP_DEPRECATED to CFLAGS to build correctly with
  OpenLDAP 2.3
* Mon Oct  3 2005 sbrabec@suse.cz
- Fixed name clash crash in fam/gamin patch (#116897).
- Fixed neededforbuild.
* Mon Sep  5 2005 sbrabec@suse.cz
- Patch to pick one of fam/gamin libraries by dlopen().
* Wed Aug 10 2005 rodrigo@suse.de
- Update to version 1.3.90, which fixes autobuild problems.
* Mon Aug  8 2005 rodrigo@suse.de
- Update to version 1.3.90
* Fri Jul  8 2005 gekker@suse.de
- Update to version 1.3.4
- Remove upstreamed patch
* Wed Jun 29 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Tue Jun 28 2005 ro@suse.de
- fix some more compiler warnings
* Tue Jun 28 2005 sbrabec@suse.cz
- Fixed devel requirements.
- Removed unneeded static modules and .la files for modules.
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Wed Jan 19 2005 ro@suse.de
- use prefix/lib/libgda in filelist
* Fri Jan 14 2005 ro@suse.de
- update to 1.2.0
- use sqlite2 for now
* Mon Nov 22 2004 ro@suse.de
- don't create empty rpm for sqlite
* Fri Nov 19 2004 ro@suse.de
- sqlite is only available for 9.1 and newer
* Thu Nov 18 2004 ro@suse.de
- updated aclocal path
* Mon Oct 25 2004 ro@suse.de
- locale rename: no -> nb
* Tue May 18 2004 ro@suse.de
- fix some compiler warnings
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Wed Mar 10 2004 sbrabec@suse.cz
- Gzip man pages.
* Mon Mar  1 2004 ro@suse.de
- fix build on ppc64 and s390x
* Wed Feb 18 2004 sbrabec@suse.cz
- Split some providers to reduce dependences (bug #34668).
* Tue Feb 17 2004 sbrabec@suse.cz
- Updated to version 1.0.3.
- Turned on sqlite backend.
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Thu Jan  8 2004 ro@suse.de
- updated neededforbuild:
  perl-XML-Parser needed for intltool
  expat needed for perl-XML-Parser
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 1.0.1.
* Fri Aug 29 2003 kukuk@suse.de
- libgda: Don't conflict with ourself
- libgda-devel: Requires libgda
* Tue Aug 26 2003 sbrabec@suse.cz
- Updated to version 0.91.0.
* Mon Aug 18 2003 sbrabec@suse.cz
- Package renamed (libgda2 -> libgda).
- Updated to version 0.12.1.
* Thu Jul 17 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Tue Jul  1 2003 ro@suse.de
- added gnome-filesystem to neededforbuild
- added directories to filelist
* Wed Jun  4 2003 ro@suse.de
- run full autoreconf
- fix configure.in for lib64 platforms
* Wed Jun  4 2003 sbrabec@suse.cz
- Initial SuSE version of GNOME2 port.
